#
# spec file for package dmidecode
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           dmidecode
Version:        3.1
Release:        lp150.3.3.1
Summary:        DMI table decoder
License:        GPL-2.0+
Group:          System/Console
Url:            http://www.nongnu.org/dmidecode/
Source0:        http://download.savannah.gnu.org/releases/%{name}/%{name}-%{version}.tar.xz
Source1:        http://download.savannah.gnu.org/releases/%{name}/%{name}-%{version}.tar.xz.sig
# would be, but tarball is signed by someone else without signatures.
# https://savannah.nongnu.org/project/memberlist-gpgkeys.php?group=dmidecode
# Source2:        %{name}.keyring
Patch1:         dmioem-reflect-hpe-new-company-name.patch
Patch2:         dmidecode-fix-tpm-device-firmware-version.patch
Patch3:         dmioem-fix-hpe-type-219-uefi-flag.patch
Patch4:         dmidecode-extensions-to-memory-device-type-17.patch
Patch5:         dmidecode-add-logical-non-volatile-device.patch
Provides:       pmtools:%{_sbindir}/dmidecode
Obsoletes:      pmtools < 20071117
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  xz
ExclusiveArch:  %ix86 ia64 x86_64 %arm aarch64

%description
Dmidecode reports information about your system's hardware as described
in your system BIOS according to the SMBIOS/DMI standard. This
information typically includes system manufacturer, model name, serial
number, BIOS version, asset tag as well as a lot of other details of
varying level of interest and reliability depending on the
manufacturer. This will often include usage status for the CPU sockets,
expansion slots (e.g. AGP, PCI, ISA) and memory module slots, and the
list of I/O ports (e.g. serial, parallel, USB).

Beware that DMI data have proven to be too unreliable to be blindly
trusted. Dmidecode does not scan your hardware, it only reports what
the BIOS told it to.

%prep
%setup -q
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1

%build
make CFLAGS="%{optflags}" %{?_smp_mflags}

%install
install -dm 755 %{buildroot}%{_sbindir}
install -dm 755 %{buildroot}%{_mandir}/man8
install -dm 755 %{buildroot}%{_docdir}/%{name}
%ifarch ia64 %arm aarch64
for i in dmidecode ; do
%else
for i in dmidecode vpddecode ownership biosdecode ; do
%endif
install -m 755 $i %{buildroot}%{_sbindir}/
install -m 644 man/$i.8 %{buildroot}%{_mandir}/man8/
install -m 644 AUTHORS CHANGELOG LICENSE README %{buildroot}%{_docdir}/%{name}/
done

%files
%defattr(-,root,root)
%{_sbindir}/*
%doc %{_docdir}/%{name}
%{_mandir}/man8/*

%changelog
* Tue Jan 29 2019 jdelvare@suse.de
- dmidecode-extensions-to-memory-device-type-17.patch: dmidecode:
  Extensions to Memory Device (Type 17) (FATE#326830 bsc#1120149)
- dmidecode-add-logical-non-volatile-device.patch: Add "Logical
  non-volatile device" to the memory device types (FATE#326830
  bsc#1120149)
* Tue Apr 17 2018 jdelvare@suse.de
- dmioem-reflect-hpe-new-company-name.patch: Reflect HPE's new
  company name.
- dmidecode-fix-tpm-device-firmware-version.patch: Fix firmware
  version of TPM device.
- dmioem-fix-hpe-type-219-uefi-flag.patch: Fix the reporting of
  HP/HPE UEFI feature.
* Mon Jul 17 2017 jdelvare@suse.de
- Add missing bug numbers and FATE references in changes file
  (bsc#1041670).
* Wed May 24 2017 jdelvare@suse.de
- Update to upstream version 3.1:
  * Support for SMBIOS 3.1.0 and 3.1.1. This includes new chassis
    types, new processor family names, new processor family upgrade
    names, and new slot types, as well as support of larger BIOS
    ROM sizes and cache sizes, and a new structure type (43, TPM
    Device.)
  * A new command line option to query OEM strings.
  * All error messages are now printed on stderr (#47274, #48158.)
  * Fixes a crash with SIGBUS (#46066.)
  * Various minor fixes, improvements and cleanups.
  * Obsoletes dmidecode-01-add-no-sysfs-option-description-to-h-output.patch,
    dmidecode-02-fix-no-smbios-nor-dmi-entry-point-found-on-smbios3.patch,
    dmidecode-03-let-read_file-return-the-actual-data-size.patch,
    dmidecode-04-use-read_file-to-read-the-dmi-table-from-sysfs.patch,
    dmidecode-05-use-dword-for-structure-table-maximum-size-in-smbios3.patch,
    dmidecode-06-hide-irrelevant-fixup-message.patch, and
    dmidecode-07-only-decode-one-dmi-table.patch.
* Fri Jan 20 2017 jdelvare@suse.de
- dmidecode-07-only-decode-one-dmi-table.patch: Only decode one
  DMI table.
  https://savannah.nongnu.org/bugs/?50022
* Tue May  3 2016 jdelvare@suse.de
- dmidecode-01-add-no-sysfs-option-description-to-h-output.patch:
  Add "--no-sysfs" option description to -h output.
- dmidecode-02-fix-no-smbios-nor-dmi-entry-point-found-on-smbios3.patch:
  Fix 'No SMBIOS nor DMI entry point found' on SMBIOS3.
- dmidecode-03-let-read_file-return-the-actual-data-size.patch:
  Let read_file return the actual data size.
- dmidecode-04-use-read_file-to-read-the-dmi-table-from-sysfs.patch:
  Use read_file() to read the DMI table from sysfs.
  https://savannah.nongnu.org/bugs/?46176
- dmidecode-05-use-dword-for-structure-table-maximum-size-in-smbios3.patch:
  Use DWORD for Structure table maximum size in SMBIOS3.
- dmidecode-06-hide-irrelevant-fixup-message.patch:
  Hide irrelevant fixup message.
  http://savannah.nongnu.org/support/?109024
* Thu Sep  3 2015 jdelvare@suse.de
- Update to upstream version 3.0 (FATE#320746, FATE#320773):
  * Adds support for SMBIOS 3.0. This includes a new (64-bit) entry
    point format and new enumerated values for recent hardware.
  * Adds support for the new kernel interface (as of Linux v4.2) as
    an alternative to relying on /dev/mem to access the entry point
    and DMI table.
  * Adds decoding of Acer-specific DMI type 170 and HP-specific DMI
    types 212, 219 and 233.
  * Obsoletes dmidecode-1.173-drop-cast.patch,
    dmidecode-1.175-fix-SMBIOS-2.8.0.patch,
    dmidecode-1.176-SMBIOS-2.8-is-supported.patch,
    dmidecode-1.177-decode-pcie3-slot-id.patch,
    dmidecode-1.181-decode-CPUID-recent-AMD.patch, and
    dmidecode-1.182-decode-ddr4-memory-type.patch.
  * Various minor fixes and clean-ups.
  * Skip the SMBIOS version comparison in quiet mode (bsc#974862).
* Sun Feb 22 2015 meissner@suse.com
- dmidecode.keyring was empty, reference the savannah keyring.
  but the tarball is signed by someone unknown without gpg signatures,
  so no keyring for now.
* Fri Feb 20 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Add gpg signature
* Mon Oct 13 2014 jdelvare@suse.de
- dmidecode-1.181-decode-CPUID-recent-AMD.patch: Decode the CPUID
  of recent AMD processors (DMI type 4).
- dmidecode-1.182-decode-ddr4-memory-type.patch: Add support for
  DDR4 memory type (DMI type 17) (bsc#955705).
  https://savannah.nongnu.org/bugs/?43370
* Mon Jan 13 2014 jdelvare@suse.de
- dmidecode-1.176-SMBIOS-2.8-is-supported.patch: Bump
  SUPPORTED_SMBIOS_VER so that SMBIOS 2.8 implementations don't
  trigger a warning.
- dmidecode-1.177-decode-pcie3-slot-id.patch: Decode ID of PCI
  Express 3 slots (DMI type 9.)
  https://savannah.nongnu.org/bugs/?40178
* Fri Apr 26 2013 guillaume@opensuse.org
- Enable build for ARM
* Wed Apr 24 2013 jdelvare@suse.de
- Update to upstream version 2.12:
  * Adds support for SMBIOS 2.8. This includes new enumerated
    values for recent hardware.
  * Obsoletes dmidecode-add-SMBIOS-2_7_1-support.patch and
    dmidecode-fix-memory-array-location-overrun.patch.
  * Various minor fixes and clean-ups.
- dmidecode-1.173-drop-cast.patch: Drop unneeded and possibly
  dangerous cast.
- dmidecode-1.175-fix-SMBIOS-2.8.0.patch: Fix support for new
  processor upgrade types (DMI type 4) and new memory device type
  (DMI type 17.)
* Mon Mar 25 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Wed Apr 13 2011 jdelvare@suse.de
- dmidecode-add-SMBIOS-2_7_1-support.patch: Add enumerated values
  from SMBIOS 2.7.1.
* Tue Jan 25 2011 jdelvare@suse.de
- dmidecode-fix-memory-array-location-overrun.patch: Fix boundary
  checks of memory array location codes (DMI type 16).
* Thu Jan 20 2011 jdelvare@suse.de
- Update to upstream version 2.11:
  * Adds support for SMBIOS 2.6.1 and 2.7. This includes new
    enumerated values for recent hardware.
  * Obsoletes dmidecode-fix-makefile-for-GNU-make-3.82.patch.
  * Various minor fixes and clean-ups.
* Wed Sep  8 2010 jdelvare@suse.de
- dmidecode-fix-makefile-for-GNU-make-3.82.patch: Drop BSD make
  command in Makefile, as GNU make 3.82 chokes on it.
* Tue May  5 2009 coolo@suse.de
- obsolete pmtools, but do not provide it as it's not a rename
* Wed Mar 25 2009 jdelvare@suse.de
- Initial packaging. Historically, dmidecode had been part of the
  pmtools package, but it didn't make that much sense so it now has
  its own package.
- Initial version: 2.10.
